==> index_now-1.0.1.tar.gz: index_now/src/Form/ModuleSettingsForm.php <==
<?php

namespace Drupal\index_now\Form;

use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Module settings form.
 */
class ModuleSettingsForm extends ConfigFormBase {

  /**
   * The node types list.
   *
   * @var array
   */
  protected $nodeTypes;

  /**
   * The vocabularies list.
   *
   * @var array
   */
  protected $vocabularies;

  /**
   * The Uuid service.
   *
   * @var \Drupal\Component\Uuid\Php
   */
  protected $uuid;

  /**
   * The form construct.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Component\Uuid\UuidInterface $uuid
   *   The uuid service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager,
    UuidInterface $uuid
  ) {
    parent::__construct($config_factory);
    $this->nodeTypes = $entity_type_manager->getStorage('node_type')->loadMultiple();
    $this->vocabularies = $entity_type_manager->getStorage('taxonomy_vocabulary')->loadMultiple();
    $this->uuid = $uuid;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('uuid')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'index_now_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'index_now.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $filename = DRUPAL_ROOT . "/index_now_key.txt";
    if (!file_exists($filename)) {
      // We dont use service messenger because the warning remains
      // after the file has been generated until we reload the page.
      $form['no_keyfile'] = [
        '#markup' => "<p>⚠️ " . $this->t("Index now key file has not been generated yet. You must genereate this file if you want to use Index Now on this environment.") . "</p>",
      ];

      $form['generate_keyfile'] = [
        '#type' => 'button',
        '#value' => $this->t("Generate key file"),
        '#name' => 'generate_keyfile',
        '#attributes' => [
          'class' => [
            'button',
            'button-primary',
          ],
        ],
      ];
    }

    $form['tabs'] = [
      '#type' => 'vertical_tabs',
      '#title' => $this->t("Restrict use"),
    ];

    $form['node'] = [
      '#type' => 'details',
      '#title' => $this->t("Content types"),
      '#group' => 'tabs',
    ];

    $node_types = [];
    /** @var \Drupal\node\Entity\NodeType $node_type */
    foreach ($this->nodeTypes as $machine_name => $node_type) {
      $node_types[$machine_name] = $node_type->get('name');
    }

    $form['node']['exclude_node_types'] = [
      '#type' => 'checkboxes',
      '#options' => $node_types,
      '#title' => $this->t("Exclude node types"),
      '#description' => $this->t("Selected node type(s) won't use Index now"),
      '#default_value' => $this->configFactory->getEditable('index_now.settings')
        ->get('exclude_node_types'),
    ];

    $form['taxonomy'] = [
      '#type' => 'details',
      '#title' => $this->t("Taxonomies"),
      '#group' => 'tabs',
    ];

    $vocabularies = [];
    /** @var \Drupal\taxonomy\Entity\Vocabulary $vocabulary */
    foreach ($this->vocabularies as $machine_name => $vocabulary) {
      $vocabularies[$machine_name] = $vocabulary->get('name');
    }

    $form['taxonomy']['exclude_vocabularies'] = [
      '#type' => 'checkboxes',
      '#options' => $vocabularies,
      '#title' => $this->t("Exclude node types"),
      '#description' => $this->t("Selected node type(s) won't use Index now"),
      '#default_value' => $this->configFactory->getEditable('index_now.settings')
        ->get('exclude_vocabularies'),
    ];

    $form['default_engine'] = [
      '#type' => 'radios',
      '#options' => [
        'bing' => 'Microsoft Bing',
        'yandex' => 'Yandex',
      ],
      '#title' => $this->t("Default search engine to interact with"),
      '#description' => $this->t("Since november 2021, if you interact with one search engine, you interact with all."),
      '#default_value' => $this->configFactory->getEditable('index_now.settings')
        ->get('default_engine') ?? 'bing',
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    if ($triggering_element['#name'] == 'generate_keyfile') {
      // Try to retrieve the API key if it exists (from index_now.settings.yml).
      $uuid = $this->configFactory->getEditable('index_now.settings')
        ->get('apikey');

      if (empty($uuid)) {
        // Generate an API key.
        $uuid = $this->uuid->generate();

        // Store the API key as a config data.
        $this->configFactory->getEditable('index_now.settings')
          ->set('apikey', $uuid)
          ->save();
      }
      // Create a file in the root folder which will store the API key.
      $filename = DRUPAL_ROOT . "/index_now_key.txt";
      file_put_contents($filename, $uuid);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('index_now.settings')
      ->set('exclude_node_types', $form_state->getValue('exclude_node_types'))
      ->set('exclude_vocabularies', $form_state->getValue('exclude_vocabularies'))
      ->set('default_engine', $form_state->getValue('default_engine'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}

==> index_now-1.0.2.tar.gz: index_now/src/Form/ModuleSettingsForm.php <==
<?php

namespace Drupal\index_now\Form;

use Drupal\Component\Uuid\UuidInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Module settings form.
 */
class ModuleSettingsForm extends ConfigFormBase {

  /**
   * The node types list.
   *
   * @var array
   */
  protected $nodeTypes;

  /**
   * The vocabularies list.
   *
   * @var array
   */
  protected $vocabularies;

  /**
   * The Uuid service.
   *
   * @var \Drupal\Component\Uuid\Php
   */
  protected $uuid;

  /**
   * The form construct.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Component\Uuid\UuidInterface $uuid
   *   The uuid service.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    EntityTypeManagerInterface $entity_type_manager,
    UuidInterface $uuid
  ) {
    parent::__construct($config_factory);
    $this->nodeTypes = $entity_type_manager->getStorage('node_type')->loadMultiple();
    $this->vocabularies = $entity_type_manager->getStorage('taxonomy_vocabulary')->loadMultiple();
    $this->uuid = $uuid;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('entity_type.manager'),
      $container->get('uuid')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'index_now_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'index_now.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $filename = DRUPAL_ROOT . "/index_now_key.txt";
    if (!file_exists($filename)) {
      // We dont use service messenger because the warning remains
      // after the file has been generated until we reload the page.
      $form['no_keyfile'] = [
        '#markup' => "<p>⚠️ " . $this->t("Index now key file has not been generated yet. You must genereate this file if you want to use Index Now on this environment.") . "</p>",
      ];

      $form['generate_keyfile'] = [
        '#type' => 'button',
        '#value' => $this->t("Generate key file"),
        '#name' => 'generate_keyfile',
        '#attributes' => [
          'class' => [
            'button',
            'button-primary',
          ],
        ],
      ];
    }

    $form['tabs'] = [
      '#type' => 'vertical_tabs',
      '#title' => $this->t("Restrict use"),
    ];

    $form['node'] = [
      '#type' => 'details',
      '#title' => $this->t("Content types"),
      '#group' => 'tabs',
    ];

    $node_types = [];
    /** @var \Drupal\node\Entity\NodeType $node_type */
    foreach ($this->nodeTypes as $machine_name => $node_type) {
      $node_types[$machine_name] = $node_type->get('name');
    }

    $form['node']['exclude_node_types'] = [
      '#type' => 'checkboxes',
      '#options' => $node_types,
      '#title' => $this->t("Exclude node types"),
      '#description' => $this->t("Selected node types won't use Index now"),
      '#default_value' => $this->configFactory->getEditable('index_now.settings')
        ->get('exclude_node_types'),
    ];

    $form['taxonomy'] = [
      '#type' => 'details',
      '#title' => $this->t("Taxonomies"),
      '#group' => 'tabs',
    ];

    $vocabularies = [];
    /** @var \Drupal\taxonomy\Entity\Vocabulary $vocabulary */
    foreach ($this->vocabularies as $machine_name => $vocabulary) {
      $vocabularies[$machine_name] = $vocabulary->get('name');
    }

    $form['taxonomy']['exclude_vocabularies'] = [
      '#type' => 'checkboxes',
      '#options' => $vocabularies,
      '#title' => $this->t("Exclude vocabularies"),
      '#description' => $this->t("Selected vocabularies won't use Index now"),
      '#default_value' => $this->configFactory->getEditable('index_now.settings')
        ->get('exclude_vocabularies'),
    ];

    $form['default_engine'] = [
      '#type' => 'radios',
      '#options' => [
        'bing' => 'Microsoft Bing',
        'yandex' => 'Yandex',
      ],
      '#title' => $this->t("Default search engine to interact with"),
      '#description' => $this->t("Since november 2021, if you interact with one search engine, you interact with all."),
      '#default_value' => $this->configFactory->getEditable('index_now.settings')
        ->get('default_engine') ?? 'bing',
      '#required' => TRUE,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    $triggering_element = $form_state->getTriggeringElement();
    if ($triggering_element['#name'] == 'generate_keyfile') {
      // Try to retrieve the API key if it exists (from index_now.settings.yml).
      $uuid = $this->configFactory->getEditable('index_now.settings')
        ->get('apikey');

      if (empty($uuid)) {
        // Generate an API key.
        $uuid = $this->uuid->generate();

        // Store the API key as a config data.
        $this->configFactory->getEditable('index_now.settings')
          ->set('apikey', $uuid)
          ->save();
      }
      // Create a file in the root folder which will store the API key.
      $filename = DRUPAL_ROOT . "/index_now_key.txt";
      file_put_contents($filename, $uuid);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->configFactory->getEditable('index_now.settings')
      ->set('exclude_node_types', $form_state->getValue('exclude_node_types'))
      ->set('exclude_vocabularies', $form_state->getValue('exclude_vocabularies'))
      ->set('default_engine', $form_state->getValue('default_engine'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
